pub fn deserialize_from_reader<R, O>(reader: R) -> Result<O>where
R: Read,
O: DeserializeOwned,Expand description
Deserializes a serde_json object from reader with the recursion limit disabled.
Must be used for all JSON I/O to avoid crashes due to the aforementioned limit.