pub struct ContractIdentifier {
pub path: String,
pub name: Option<String>,
pub full_path: String,
}Expand description
This structure simplifies passing the contract identifiers through the compilation pipeline.
Fields
path: StringThe absolute file path.
name: Option<String>The contract name. Is set for Solidity contracts only. Otherwise it would be equal to the file name.
full_path: StringThe full contract identifier.
For Solidity, The format is <absolute file path>:<contract name>.
For other languages, <absolute file path>.
Implementations